#
# spec file for package python-certbot-dns-google
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-certbot-dns-google
Version:        3.1.0
Release:        1.1
Summary:        Google Cloud Authenticator plugin for Certbot
License:        Apache-2.0
URL:            https://github.com/certbot/certbot
Source:         https://files.pythonhosted.org/packages/source/c/certbot-dns-google/certbot_dns_google-%{version}.tar.gz
BuildRequires:  %{python_module certbot >= %{version}}
BuildRequires:  %{python_module google-api-python-client >= 1.6.5}
BuildRequires:  %{python_module google-auth >= 2.16.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-acme >= %{version}
Requires:       python-certbot >= %{version}
Requires:       python-google-api-python-client >= 1.6.5
Requires:       python-google-auth >= 2.16.0
BuildArch:      noarch
%python_subpackages

%description
Google Cloud DNS Authenticator plugin for Certbot.

%prep
%autosetup -p1 -n certbot_dns_google-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/certbot_dns_google
%{python_sitelib}/certbot_dns_google-%{version}*info

%changelog
* Mon Jan 27 2025 Markéta Machová <mmachova@suse.com>
- update to version 3.1.0
  * sync with the main certbot package
- convert to pip-based build
* Tue Dec  3 2024 Markéta Machová <mmachova@suse.com>
- update to version 3.0.1
  * sync with the main certbot package
* Tue Jun 25 2024 Markéta Machová <mmachova@suse.com>
- update to version 2.11.0
  * sync with the main certbot package
* Fri Feb  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * Support for Python 3.12 was added.
  * Updates `joinpath` syntax to only use one addition per call,
    because the multiple inputs version was causing mypy errors
    on Python 3.10.
  * Makes the `reconfigure` verb actually use the staging server
    for the dry run to check the new configuration.
* Wed Feb  7 2024 Markéta Machová <mmachova@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Dec  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.8.0
  * sync with the main certbot package
* Thu Nov 16 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.4
  * sync with the main certbot package
* Tue Oct 31 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.3
  * Filter zones in certbot-dns-google to avoid usage of private DNS zones to create records
* Wed Jun  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.6.0
  * Support for Python 3.11 was added to Certbot and all of its components.
  * All Certbot components now require pytest to run tests.
  * Packaged tests for all Certbot components besides josepy were moved inside the _internal/tests module.
  * There is now a new Other annotated challenge object to allow plugins to support entirely novel challenges.
  * --dns-google-project optionally allows for specifying the project that the DNS zone(s) reside in, which
    allows for Certbot usage in scenarios where the auth credentials reside in a different project to the zone(s)
    that are being managed.
  * certbot-dns-google now loads credentials using the standard Application Default Credentials strategy, rather
    than explicitly requiring the Google Compute metadata server to be present if a service account is not provided
    using --dns-google-credentials.
  * --dns-google-credentials now supports additional types of file-based credential, such as
    External Account Credentials created by Workload Identity Federation. All file-based credentials implemented
    by the Google Auth library are supported.
  * certbot-dns-google no longer requires deprecated oauth2client library.
  * Certbot no longer depends on zope.
- Drop certbot-pr8928-replace-oauth2client.patch
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.31.0
  * sync with the main certbot package
* Wed Sep 21 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.30.0
  * sync with the main certbot package
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * --allow-subset-of-names will now additionally retry in cases where domains
    are rejected while creating or finalizing orders. This requires subproblem
    support from the ACME server
  * The show_account subcommand now uses the "newAccount" ACME endpoint to
    fetch the account data, so it doesn't rely on the locally stored account URL.
    This fixes situations where Certbot
    would use old ACMEv1 registration info with non-functional account URLs.
  * The generated Certificate Signing Requests are now generated as version 1
    instead of version 3. This resolves situations in where strict enforcement
    of PKCS#10 meant that CSRs that were generated as version 3 were rejected
* Fri Jun 24 2022 Dirk Müller <dmueller@suse.com>
- update to version 1.28.0
  * sync with the main certbot package
* Mon May 30 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.27.0
  * sync with the main certbot package
* Thu Apr 14 2022 Ben Greiner <code@bnavigator.de>
- Add certbot-pr8928-replace-oauth2client.patch
  gh#certbot/certbot#8928
* Fri Apr  8 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.26.0
  * GCP Permission list for certbot-dns-google in plugin documentation
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.22.0
  * sync with the main certbot package
* Mon Dec 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop python 3.6 support since python-google-api-python-client
  dropped it
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with the main certbot package
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * sync with the main certbot package
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * Require the latest certbot and acme plugins for simplicity
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with the main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * sync with the main certbot package
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  + Fixed
  * certbot-dns-google would sometimes crash with HTTP 409/412
    errors when used with very large zones. See #6036.
  * certbot-dns-google would sometimes crash with an HTTP 412
    error if preexisting records had an unexpected TTL, i.e.:
    different than Certbot's default TTL for this plugin.
    See #8551.
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * Sync with main certbot package.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * Sync with main certbot package.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Sync with main certbot package.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Sync with main certbot package.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Sync with main certbot package.
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Sync with main certbot package.
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Sync with main certbot package.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Sync with main certbot package.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0
  * sync with main certbot package
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * Updated certbot-dns-google to depend on newer versions of
    google-api-python-client and oauth2client.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * sync with main certbot package
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.37.2
  * sync with main certbot package
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * sync with main certbot package
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.35.1
  * sync with main certbot package
* Sun May 19 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.2:
  * sync with main certbot package
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.32.0
  * sync with main certbot package
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.31.0
  * sync with main certbot package
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.30.2:
  * Minor logging fixes
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * sync with main certbot package
* Mon Sep  3 2018 Marketa Calabkova <mcalabkova@suse.com>
- Split the module from the main certbot package
